@@ -680,8 +680,8 @@ bool RewriteUtils::replaceExpr(const Expr *E,
   int RangeSize = TheRewriter->getRangeSize(ExprRange);
   if (RangeSize == -1) {
     SourceLocation StartLoc = ExprRange.getBegin();
-    if (SrcManager->isMacroBodyExpansion(StartLoc)) {
-      StartLoc = SrcManager->getFileLoc(StartLoc);
+    if (StartLoc.isMacroID()) {
+      StartLoc = SrcManager->getExpansionLoc(StartLoc);
     }
     SourceLocation EndLoc = ExprRange.getEnd();
     if (SrcManager->isMacroBodyExpansion(EndLoc) ||
@@ -979,6 +979,25 @@ bool RewriteUtils::replaceFunctionDeclName(const FunctionDecl *FD,
   // applying getNameAsString() on SomeClass() gives us SomeClass<T>.
 
   DeclarationNameInfo NameInfo = FD->getNameInfo();
+  if (const IdentifierInfo *IdInfo = FD->getLiteralIdentifier()) {
+    SourceLocation OpLoc = NameInfo.getBeginLoc();
+    const char *OpStartBuf = SrcManager->getCharacterData(OpLoc);
+
+    // skip string operator
+    std::string TmpStr(OpStartBuf,
+                       TheRewriter->getRangeSize(NameInfo.getSourceRange()));
+    std::string OperatorStr = "operator";
+    size_t Pos = TmpStr.find(OperatorStr);
+    TransAssert(Pos != std::string::npos && "cannot find operator!");
+
+    size_t OldNamePos =
+      TmpStr.find(IdInfo->getNameStart(), Pos, IdInfo->getLength());
+    TransAssert(OldNamePos != std::string::npos && "cannot find old name!");
+
+    SourceLocation NewStartLoc = OpLoc.getLocWithOffset(OldNamePos);
+    return !TheRewriter->ReplaceText(NewStartLoc, IdInfo->getLength(), NameStr);
+  }
+
   DeclarationName DeclName = NameInfo.getName();
   DeclarationName::NameKind K = DeclName.getNameKind();
   TransAssert((K != DeclarationName::CXXDestructorName) &&
@@ -1592,11 +1611,13 @@ SourceRange RewriteUtils::getFileLocSourceRange(SourceRange LocRange)
 {
   SourceLocation StartLoc = LocRange.getBegin();
   if (StartLoc.isMacroID()) {
-    StartLoc = SrcManager->getSpellingLoc(StartLoc);
-    SourceLocation EndLoc = LocRange.getEnd();
-    TransAssert(EndLoc.isMacroID() && "EndLoc is not from a macro!");
-    LocRange = SourceRange(StartLoc, SrcManager->getSpellingLoc(EndLoc));
+    StartLoc = SrcManager->getFileLoc(StartLoc);
   }
+  SourceLocation EndLoc = LocRange.getEnd();
+  if (EndLoc.isMacroID()) {
+    EndLoc = SrcManager->getFileLoc(EndLoc);
+  }
+  LocRange = SourceRange(StartLoc, EndLoc);
   return LocRange;
 }
 
