@@ -268,7 +268,9 @@ const Expr *Transformation::getInitExprFromBase(const Expr *BaseE,
 
   const ValueDecl *OrigDecl = DRE->getDecl();
   const VarDecl *VD = dyn_cast<VarDecl>(OrigDecl);
-  TransAssert(VD && "Bad VarDecl!");
+  if (!VD)
+    return NULL;
+
   const Type * Ty = VD->getType().getTypePtr();
   if (Ty->isPointerType())
     return NULL;
@@ -393,7 +395,7 @@ unsigned int Transformation::getConstArraySize(
   std::stringstream TmpSS(IntStr.str().str());
 
   if (!(TmpSS >> Sz)) {
-    TransAssert(0 && "Non-integer value!");
+    return UINT_MAX;
   }
   return Sz;
 }
